@@ -56,6 +56,11 @@ struct _GnomePilotPDialogPrivate
 
 	GtkWidget *pilot_name;
 	GtkWidget *pilot_basedir;
+#ifdef PILOT_LINK_0_12
+	GtkWidget *pilot_charset;
+#endif
+	GtkWidget *pilot_charset_label;
+	GtkWidget *pilot_charset_combo;
 
 	GtkWidget *sync_dialog;
 };
@@ -133,10 +138,13 @@ init (GnomePilotPDialog *gppd)
 	gppd->priv = priv;
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "PilotSettings", NULL);
+	priv->xml = glade_xml_new ("gpilotd-capplet.glade", "PilotSettings", NULL);
 	if (!priv->xml) {
-		g_message ("gnome-pilot-pdialog init(): Could not load the Glade XML file!");
-		goto error;
+		priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "PilotSettings", NULL);
+		if (!priv->xml) {
+			g_message ("gnome-pilot-pdialog init(): Could not load the Glade XML file!");
+			goto error;
+		}
 	}
 
 	if (!get_widgets (gppd)) {
@@ -205,6 +213,11 @@ get_widgets (GnomePilotPDialog *gppd)
 	
 	priv->pilot_name = GW ("pilot_name_entry");
 	priv->pilot_basedir = GW ("pilot_basedir_entry");
+	priv->pilot_charset_label = GW ("pilot_charset_label");
+	priv->pilot_charset_combo = GW ("pilot_charset_combo");
+#ifdef PILOT_LINK_0_12
+	priv->pilot_charset = GW ("pilot_charset_entry");
+#endif
 	
 #undef GW
 	return (priv->dialog
@@ -213,7 +226,12 @@ get_widgets (GnomePilotPDialog *gppd)
 		&& priv->pilot_get
 		&& priv->pilot_send
 		&& priv->pilot_name
-		&& priv->pilot_basedir);
+		&& priv->pilot_basedir
+#ifdef PILOT_LINK_0_12
+		&& priv->pilot_charset
+#endif
+		&& priv->pilot_charset_label
+		&& priv->pilot_charset_combo);
 }
 
 static void
@@ -227,6 +245,9 @@ map_widgets (GnomePilotPDialog *gppd)
 	gtk_object_set_data (GTK_OBJECT (gppd), "pilotid", priv->pilot_id);
 	gtk_object_set_data (GTK_OBJECT (gppd), "pilotname", priv->pilot_name);
 	gtk_object_set_data (GTK_OBJECT (gppd), "basedir", priv->pilot_basedir);
+#ifdef PILOT_LINK_0_12
+	gtk_object_set_data (GTK_OBJECT (gppd), "charset", priv->pilot_charset);
+#endif
 }
 
 static void 
@@ -266,6 +287,12 @@ fill_widgets (GnomePilotPDialog *gppd)
 
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_name), priv->pilot->name);
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_basedir), priv->pilot->sync_options.basedir);
+#ifndef PILOT_LINK_0_12
+		gtk_widget_set_sensitive (priv->pilot_charset_label, FALSE);
+		gtk_widget_set_sensitive (priv->pilot_charset_combo, FALSE);
+#else
+		gtk_entry_set_text (GTK_ENTRY (priv->pilot_charset), priv->pilot->pilot_charset);
+#endif
 	}
 }
 
@@ -282,9 +309,15 @@ gnome_pilot_pdialog_run_and_close (GnomePilotPDialog *gppd, GtkWindow *parent)
 		btn = gtk_dialog_run (GTK_DIALOG (priv->dialog));
 	
 		if (btn == GTK_RESPONSE_OK) {
-			if(check_base_directory(gtk_entry_get_text(
+			if(
+#ifdef PILOT_LINK_0_12
+			    check_pilot_charset(gtk_entry_get_text(
+				GTK_ENTRY(priv->pilot_charset))) &&
+#endif
+			    check_base_directory(gtk_entry_get_text(
 				GTK_ENTRY(priv->pilot_basedir)))) {
-				read_pilot_config (GTK_OBJECT (gppd), priv->pilot);
+				read_pilot_config (GTK_OBJECT (gppd),
+				    priv->pilot);
 				break;
 			}
 		} else {
@@ -337,7 +370,11 @@ gppd_userinfo_requested (GnomePilotClient *gpc,
 
 	if (priv->pilot->pilot_username) 
 		g_free (priv->pilot->pilot_username);
+#ifndef PILOT_LINK_0_12
 	if (!user->username || (convert_FromPilotChar ("UTF-8", user->username, strlen (user->username), &priv->pilot->pilot_username ) == -1)) {
+#else
+	if (!user->username || (convert_FromPilotChar_WithCharset ("UTF-8", user->username, strlen (user->username), &priv->pilot->pilot_username, NULL ) == -1)) {
+#endif
   		priv->pilot->pilot_username = g_strdup (user->username);
 	}
 
@@ -450,7 +487,11 @@ gppd_pilot_send (GtkWidget *widget, gpointer user_data)
 		read_pilot_config (GTK_OBJECT (gppd), pilot);
 
 		user.userID = pilot->pilot_id;
+#ifndef PILOT_LINK_0_12
 		if (! pilot->pilot_username || (convert_ToPilotChar ("UTF-8", pilot->pilot_username,strlen(pilot->pilot_username),&user.username) == -1)) {
+#else
+		if (! pilot->pilot_username || (convert_ToPilotChar_WithCharset ("UTF-8", pilot->pilot_username, strlen(pilot->pilot_username), &user.username, NULL) == -1)) {
+#endif
 			user.username = g_strdup (pilot->pilot_username);
 		}
 		if (gnome_pilot_client_set_user_info (priv->gpc, 
