@@ -1,5 +1,5 @@
 /* gnome-pilot-conduit-standard-abs.h
- * Copyright (C) 1999  J. Arthur Random
+ * Copyright (C) 1999  Free Software Foundation
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -15,7 +15,13 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
+ *
+ * Authors: Johnathan Blandford
+ *          Eskil Heyn Olsen
+ *          Vadim Strizhevsky
+ *
  */
+
 #ifndef __GNOME_PILOT_CONDUIT_STANDARD_ABS_H__
 #define __GNOME_PILOT_CONDUIT_STANDARD_ABS_H__
 
@@ -107,9 +113,6 @@ struct _GnomePilotConduitStandardAbsClass
 				 PilotRecord *remote);
 	int (*store_remote)	(GnomePilotConduitStandardAbs *conduit,
 				 PilotRecord *remote);
-	int (*clear_status_archive_local)
-				(GnomePilotConduitStandardAbs *conduit,
-				 LocalRecord *local);
 	int (*iterate)		(GnomePilotConduitStandardAbs *conduit,
 				 LocalRecord **local);
 	int (*iterate_specific)	(GnomePilotConduitStandardAbs *conduit,
@@ -120,9 +123,6 @@ struct _GnomePilotConduitStandardAbsClass
 	int (*set_status)	(GnomePilotConduitStandardAbs *conduit,
 				 LocalRecord *local,
 				 gint status);
-	int (*set_archived)	(GnomePilotConduitStandardAbs *conduit,
-				 LocalRecord *local,
-				 gint archived);
 	int (*set_pilot_id)	(GnomePilotConduitStandardAbs *conduit,
 				 LocalRecord *local,
 				 guint32 ID);
@@ -144,7 +144,7 @@ struct _GnomePilotConduitStandardAbsClass
 };
 
 GtkType    gnome_pilot_conduit_standard_abs_get_type (void);
-GtkObject *gnome_pilot_conduit_standard_abs_new (const char *db_name,
+GtkObject *gnome_pilot_conduit_standard_abs_new (char *db_name,
 						 guint32 creator_id);
 gint gnome_pilot_conduit_standard_abs_match_record (GnomePilotConduitStandardAbs *conduit,
 						    LocalRecord **local,
@@ -158,8 +158,6 @@ gint gnome_pilot_conduit_standard_abs_archive_remote (GnomePilotConduitStandardA
 						      PilotRecord *remote);
 gint gnome_pilot_conduit_standard_abs_store_remote (GnomePilotConduitStandardAbs *conduit,
 						    PilotRecord *remote);
-gint gnome_pilot_conduit_standard_abs_clear_status_archive_local (GnomePilotConduitStandardAbs *conduit,
-								  LocalRecord *local);
 gint gnome_pilot_conduit_standard_abs_iterate (GnomePilotConduitStandardAbs *conduit,
 					       LocalRecord **local);
 gint gnome_pilot_conduit_standard_abs_iterate_specific (GnomePilotConduitStandardAbs *conduit,
@@ -170,9 +168,6 @@ gint gnome_pilot_conduit_standard_abs_purge (GnomePilotConduitStandardAbs *condu
 gint gnome_pilot_conduit_standard_abs_set_status (GnomePilotConduitStandardAbs *conduit,
 						  LocalRecord *local,
 						  gint status);
-gint gnome_pilot_conduit_standard_abs_set_archived (GnomePilotConduitStandardAbs *conduit,
-						    LocalRecord *local,
-						    gint archived);
 gint gnome_pilot_conduit_standard_abs_set_pilot_id (GnomePilotConduitStandardAbs *conduit,
 						    LocalRecord *local,
 						    guint32 id);
