@@ -16,7 +16,10 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: gnome-pilot-dbinfo.h,v 1.6 1999/12/14 03:26:10 eskil Exp $
+ * Authors: Johnathan Blandford
+ *           Eskil Olsen
+ *
+ * $Id: gnome-pilot-dbinfo.h 931 2001-04-25 03:24:55Z eskil $
  */
 
 #ifndef __GNOME_PILOT_DBINFO_H__
@@ -26,6 +29,8 @@
 #include <pi-source.h>
 #include <pi-dlp.h>
 
+#include "gnome-pilot-structures.h"
+
 /*
   GnomePilotDBInfo is the structured used between manager.c and gnome-pilot-conduits
   to let the conduit have access to essential data reg. the current connection.
@@ -37,8 +42,6 @@
 #define PI_DBINFO(obj)				((struct DBInfo *) obj)
 #define GNOME_PILOT_DBINFO(obj)			((GnomePilotDBInfo *) obj)
 
-struct GPilotPilot;
-
 typedef struct _GnomePilotDBInfo     GnomePilotDBInfo;
 
 struct _GnomePilotDBInfo
@@ -49,7 +52,7 @@ struct _GnomePilotDBInfo
 	struct PilotUser *pu;
 
 	/* The pilot identification structure */
-	struct GPilotPilot *pilotInfo;
+	GPilotPilot *pilotInfo;
 	
 	/* This is "filedescriptor" used for pi_ calls */
 	gint   pilot_socket;
