@@ -36,8 +36,8 @@
 #define g_marshal_value_peek_ulong(v)    (v)->data[0].v_ulong
 #define g_marshal_value_peek_int64(v)    (v)->data[0].v_int64
 #define g_marshal_value_peek_uint64(v)   (v)->data[0].v_uint64
-#define g_marshal_value_peek_enum(v)     (v)->data[0].v_int
-#define g_marshal_value_peek_flags(v)    (v)->data[0].v_uint
+#define g_marshal_value_peek_enum(v)     (v)->data[0].v_long
+#define g_marshal_value_peek_flags(v)    (v)->data[0].v_ulong
 #define g_marshal_value_peek_float(v)    (v)->data[0].v_float
 #define g_marshal_value_peek_double(v)   (v)->data[0].v_double
 #define g_marshal_value_peek_string(v)   (v)->data[0].v_pointer
@@ -51,10 +51,10 @@
 /* VOID:INT,POINTER (./gpmarshal.list:1) */
 void
 gp_marshal_VOID__INT_POINTER (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_POINTER) (gpointer     data1,
@@ -88,10 +88,10 @@ gp_marshal_VOID__INT_POINTER (GClosure     *closure,
 /* INT:POINTER,INT (./gpmarshal.list:2) */
 void
 gp_marshal_INT__POINTER_INT (GClosure     *closure,
-                             GValue       *return_value,
+                             GValue       *return_value G_GNUC_UNUSED,
                              guint         n_param_values,
                              const GValue *param_values,
-                             gpointer      invocation_hint,
+                             gpointer      invocation_hint G_GNUC_UNUSED,
                              gpointer      marshal_data)
 {
   typedef gint (*GMarshalFunc_INT__POINTER_INT) (gpointer     data1,
@@ -129,10 +129,10 @@ gp_marshal_INT__POINTER_INT (GClosure     *closure,
 /* INT:POINTER,POINTER (./gpmarshal.list:3) */
 void
 gp_marshal_INT__POINTER_POINTER (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef gint (*GMarshalFunc_INT__POINTER_POINTER) (gpointer     data1,
@@ -170,10 +170,10 @@ gp_marshal_INT__POINTER_POINTER (GClosure     *closure,
 /* INT:POINTER,BOOL (./gpmarshal.list:4) */
 void
 gp_marshal_INT__POINTER_BOOLEAN (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef gint (*GMarshalFunc_INT__POINTER_BOOLEAN) (gpointer     data1,
@@ -211,10 +211,10 @@ gp_marshal_INT__POINTER_BOOLEAN (GClosure     *closure,
 /* INT:POINTER,INT,INT (./gpmarshal.list:5) */
 void
 gp_marshal_INT__POINTER_INT_INT (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef gint (*GMarshalFunc_INT__POINTER_INT_INT) (gpointer     data1,
@@ -254,10 +254,10 @@ gp_marshal_INT__POINTER_INT_INT (GClosure     *closure,
 /* INT:POINTER (./gpmarshal.list:6) */
 void
 gp_marshal_INT__POINTER (GClosure     *closure,
-                         GValue       *return_value,
+                         GValue       *return_value G_GNUC_UNUSED,
                          guint         n_param_values,
                          const GValue *param_values,
-                         gpointer      invocation_hint,
+                         gpointer      invocation_hint G_GNUC_UNUSED,
                          gpointer      marshal_data)
 {
   typedef gint (*GMarshalFunc_INT__POINTER) (gpointer     data1,
@@ -293,10 +293,10 @@ gp_marshal_INT__POINTER (GClosure     *closure,
 /* INT:NONE (./gpmarshal.list:7) */
 void
 gp_marshal_INT__VOID (GClosure     *closure,
-                      GValue       *return_value,
+                      GValue       *return_value G_GNUC_UNUSED,
                       guint         n_param_values,
                       const GValue *param_values,
-                      gpointer      invocation_hint,
+                      gpointer      invocation_hint G_GNUC_UNUSED,
                       gpointer      marshal_data)
 {
   typedef gint (*GMarshalFunc_INT__VOID) (gpointer     data1,
