@@ -51,7 +51,7 @@ static const struct poptOption options[] = {
 	{"listpilots", '\0', POPT_ARG_STRING, &arg_list_by_login, 0, N_("list PDAs by login (all for all pilots)"), N_("LOGIN")},
 	{"pilot", '\0', POPT_ARG_STRING, &arg_pilot, 0, N_("Specify PDA to operate on (defaults to MyPDA)"), N_("PILOTNAME")},
 	{"cradle", '\0', POPT_ARG_STRING, &arg_cradle, 0, N_("Specify a cradle to operate on (defaults to Cradle0)"), N_("CRADLENAME")},
-	{"listbases", 'l', POPT_ARG_NONE, &arg_listbases, 0, N_("List the specifed PDA's bases"), NULL},
+	{"listbases", 'l', POPT_ARG_NONE, &arg_listbases, 0, N_("List the specified PDA's bases"), NULL},
 	{NULL, '\0', 0, NULL, 0} /* end the list */
 };
 
